import { useAjax } from "@/Hook/useAjax"
import Tables from "@/components/Tables"
import { getGameListNewApi } from "@/services/gameData"
import { getSendMsgTaskListApi } from "@/services/gameData/roleOperate"
import { SyncOutlined } from "@ant-design/icons"
import { Button, Modal, Select, Space, message } from "antd"
import React, { useEffect, useState } from "react"
import { columnsMsgTask } from "./tableConfig"

interface Props {
    sourceSystem?: string
}
/**
 * 消息推送任务列表
 * @returns 
 */
const TaskList: React.FC<Props> = ({ sourceSystem }) => {

    /****************************/
    const [visible, setVisible] = useState<boolean>(false)
    const [gameList, setGameList] = useState<any[]>([])
    const [gameId, setGameId] = useState<number>()
    const [queryForm, setQueryForm] = useState<{ pageNum: number, pageSize: number }>({ pageNum: 1, pageSize: 20 })

    const getGameListNew = useAjax((params) => getGameListNewApi(params))
    const getSendMsgTaskList = useAjax((params) => getSendMsgTaskListApi(params))
    /****************************/

    useEffect(() => {
        if (gameId && visible) {
            getSendMsgTaskList.run({ ...queryForm, gameId })
        }
    }, [queryForm, gameId, visible])

    const open = () => {
        if (sourceSystem) {
            setVisible(true)
            getGameListNew.run({ sourceSystem }).then(res => {
                const { gameList } = res
                setGameList(gameList?.map((item: { id: any; game_name: any }) => ({ id: item.id, name: item.game_name })) || [])
                setGameId(gameList?.[0]?.id)
            })
        } else {
            message.error('请选择数据源')
        }
    }



    return <>
        <Button type="primary" size="small" onClick={open}>消息推送任务列表</Button>
        <Modal
            title={<Space>
                <strong>消息推送任务列表</strong>
                <Select
                    maxTagCount={1}
                    showSearch
                    style={{ minWidth: 140 }}
                    loading={getGameListNew.loading}
                    placeholder={'请选择游戏'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                    value={gameId}
                    onChange={(e) => setGameId(e)}
                >
                    {gameList?.map((item: any) => <Select.Option value={item.id} key={item.id}>{item.name}</Select.Option>)}
                </Select>
                <Button type="link" icon={<SyncOutlined />} onClick={() => getSendMsgTaskList.refresh()} loading={getSendMsgTaskList.loading} />
            </Space>}
            visible={visible}
            onCancel={() => setVisible(false)}
            footer={null}
            width={1000}
        >
            <Tables
                bordered
                current={queryForm.pageNum}
                pageSize={queryForm.pageSize}
                columns={columnsMsgTask()}
                dataSource={getSendMsgTaskList?.data?.records}
                scroll={{ x: 1000, y: 600 }}
                onChange={(pagination: any, filters: any, sortData: any) => {
                    let { current, pageSize } = pagination
                    let newQueryForm = JSON.parse(JSON.stringify(queryForm))
                    newQueryForm.pageNum = current
                    newQueryForm.pageSize = pageSize
                    setQueryForm({ ...newQueryForm })
                }}
                size="small"
                total={getSendMsgTaskList?.data?.total}
                loading={getSendMsgTaskList?.loading}
                defaultPageSize={20}
            />
        </Modal>
    </>
}

export default React.memo(TaskList)